Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(544)

Unified Diff: src/fast-accessor-assembler.h

Issue 2741683004: [rename] Rename internal field to embedder field. (Closed)
Patch Set: DEPRECATE_SOON(GetInternalField) Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/fast-accessor-assembler.h
diff --git a/src/fast-accessor-assembler.h b/src/fast-accessor-assembler.h
index f51d5a79e829eb4db2da4026ed799b168af06123..536a6182932d87dd5b3fd8fb3be25fa23b2f158e 100644
--- a/src/fast-accessor-assembler.h
+++ b/src/fast-accessor-assembler.h
@@ -55,15 +55,15 @@ class FastAccessorAssembler {
// Builder / assembler functions:
ValueId IntegerConstant(int int_constant);
ValueId GetReceiver();
- ValueId LoadInternalField(ValueId value_id, int field_no);
+ ValueId LoadEmbedderField(ValueId value_id, int field_no);
- // Loads internal field and assumes the object is indeed a valid API object
- // with the proper internal fields present.
+ // Loads embedder field and assumes the object is indeed a valid API object
+ // with the proper embedder fields present.
// The intended use is to call this on an object whose structure has already
// been checked previously, e.g. the accessor's receiver, which is map-checked
// before the fast accessor is called on it. Using this on an arbitrary object
// will result in unsafe memory accesses.
- ValueId LoadInternalFieldUnchecked(ValueId value_id, int field_no);
+ ValueId LoadEmbedderFieldUnchecked(ValueId value_id, int field_no);
ValueId LoadValue(ValueId value_id, int offset);
ValueId LoadObject(ValueId value_id, int offset);
« include/v8-experimental.h ('K') | « src/factory.cc ('k') | src/fast-accessor-assembler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698